#ifndef NT2_INCLUDE_FUNCTIONS_LINEAR_INTERP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LINEAR_INTERP_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/linear_interp.hpp>

#endif
